==> haskell-semigroupoids-5.3.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-semigroupoids.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: semigroupoids
version: 5.3.1
id: semigroupoids-5.3.1-Fj1s1O9EzQ46dpQkDTXWuf
key: semigroupoids-5.3.1-Fj1s1O9EzQ46dpQkDTXWuf
license: BSD-3-Clause
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/semigroupoids
synopsis: Semigroupoids: Category sans id
description:
    Provides a wide array of (semi)groupoids and operations for working with them.
    .
    A '\''Semigroupoid'\'' is a '\''Category'\'' without the requirement of identity arrows for every object in the category.
    .
    A '\''Category'\'' is any '\''Semigroupoid'\'' for which the Yoneda lemma holds.
    .
    When working with comonads you often have the @\<*\>@ portion of an @Applicative@, but
    not the @pure@. This was captured in Uustalu and Vene'\''s \"Essence of Dataflow Programming\"
    in the form of the @ComonadZip@ class in the days before @Applicative@. Apply provides a weaker invariant, but for the comonads used for data flow programming (found in the streams package), this invariant is preserved. Applicative function composition forms a semigroupoid.
    .
    Similarly many structures are nearly a comonad, but not quite, for instance lists provide a reasonable '\''extend'\'' operation in the form of '\''tails'\'', but do not always contain a value.
    .
    Ideally the following relationships would hold:
    .
    > Foldable ----> Traversable <--- Functor ------> Alt ---------> Plus           Semigroupoid
    >      |               |            |                              |                  |
    >      v               v            v                              v                  v
    > Foldable1 ---> Traversable1     Apply --------> Applicative -> Alternative      Category
    >                                   |               |              |                  |
    >                                   v               v              v                  v
    >                                 Bind ---------> Monad -------> MonadPlus          Arrow
    >
    .
    Apply, Bind, and Extend (not shown) give rise the Static, Kleisli and Cokleisli semigroupoids respectively.
    .
    This lets us remove many of the restrictions from various monad transformers
    as in many cases the binding operation or @\<*\>@ operation does not require them.
    .
    Finally, to work with these weaker structures it is beneficial to have containers
    that can provide stronger guarantees about their contents, so versions of '\''Traversable'\''
    and '\''Foldable'\'' that can be folded with just a '\''Semigroup'\'' are added.
category: Control, Comonads
abi: 6b1e1638002b9d539230dd8cbea73408
exposed: True
exposed-modules:
    Data.Bifunctor.Apply Data.Functor.Alt Data.Functor.Apply
    Data.Functor.Bind Data.Functor.Bind.Class Data.Functor.Bind.Trans
    Data.Functor.Extend Data.Functor.Plus Data.Groupoid
    Data.Isomorphism Data.Semigroup.Bifoldable
    Data.Semigroup.Bitraversable Data.Semigroup.Foldable
    Data.Semigroup.Foldable.Class Data.Semigroup.Traversable
    Data.Semigroup.Traversable.Class Data.Semigroupoid
    Data.Semigroupoid.Dual Data.Semigroupoid.Ob
    Data.Semigroupoid.Static Data.Traversable.Instances
import-dirs: /usr/lib/ghc-8.4.3/site-local/semigroupoids-5.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/semigroupoids-5.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/semigroupoids-5.3.1
hs-libraries: HSsemigroupoids-5.3.1-Fj1s1O9EzQ46dpQkDTXWuf
depends:
    base-4.11.1.0 base-orphans-0.8-3Ndp0ohh7rtBqRP3qW2F5j
    bifunctors-5.5.2-FnSrewG1ygu7QtjW8DMYvn template-haskell-2.13.0.0
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    containers-0.5.11.0 contravariant-1.4.1-HAsNOXS6UjNLhhUqovtoIr
    distributive-0.5.3-IdldapDLIRvIkayXxqE7xM
    comonad-5.0.4-Kch8uZj3fHYBRHUhGoWeQU
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-orphans-0.8-3Ndp0ohh7rtBqRP3qW2F5j=a0188b579af839f9c8290c33a86ab883
             bifunctors-5.5.2-FnSrewG1ygu7QtjW8DMYvn=af8c18d7ff712debb5710f9dacbefdcf
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             contravariant-1.4.1-HAsNOXS6UjNLhhUqovtoIr=1c8446e86d39f5069240f7ab3c213859
             distributive-0.5.3-IdldapDLIRvIkayXxqE7xM=80163a307d44ca5380cd7f4342768aa0
             comonad-5.0.4-Kch8uZj3fHYBRHUhGoWeQU=5ad715071b0a7ed44c898fdbb556e2a9
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
haddock-interfaces: /usr/share/doc/haskell-semigroupoids/html/semigroupoids.haddock
haddock-html: /usr/share/doc/haskell-semigroupoids/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-semigroupoids-5.3.1-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-semigroupoids.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: semigroupoids
version: 5.3.1
id: semigroupoids-5.3.1-FqTO2wYzwLW2klA2dZbjqO
key: semigroupoids-5.3.1-FqTO2wYzwLW2klA2dZbjqO
license: BSD-3-Clause
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/semigroupoids
synopsis: Semigroupoids: Category sans id
description:
    Provides a wide array of (semi)groupoids and operations for working with them.
    .
    A '\''Semigroupoid'\'' is a '\''Category'\'' without the requirement of identity arrows for every object in the category.
    .
    A '\''Category'\'' is any '\''Semigroupoid'\'' for which the Yoneda lemma holds.
    .
    When working with comonads you often have the @\<*\>@ portion of an @Applicative@, but
    not the @pure@. This was captured in Uustalu and Vene'\''s \"Essence of Dataflow Programming\"
    in the form of the @ComonadZip@ class in the days before @Applicative@. Apply provides a weaker invariant, but for the comonads used for data flow programming (found in the streams package), this invariant is preserved. Applicative function composition forms a semigroupoid.
    .
    Similarly many structures are nearly a comonad, but not quite, for instance lists provide a reasonable '\''extend'\'' operation in the form of '\''tails'\'', but do not always contain a value.
    .
    Ideally the following relationships would hold:
    .
    > Foldable ----> Traversable <--- Functor ------> Alt ---------> Plus           Semigroupoid
    >      |               |            |                              |                  |
    >      v               v            v                              v                  v
    > Foldable1 ---> Traversable1     Apply --------> Applicative -> Alternative      Category
    >                                   |               |              |                  |
    >                                   v               v              v                  v
    >                                 Bind ---------> Monad -------> MonadPlus          Arrow
    >
    .
    Apply, Bind, and Extend (not shown) give rise the Static, Kleisli and Cokleisli semigroupoids respectively.
    .
    This lets us remove many of the restrictions from various monad transformers
    as in many cases the binding operation or @\<*\>@ operation does not require them.
    .
    Finally, to work with these weaker structures it is beneficial to have containers
    that can provide stronger guarantees about their contents, so versions of '\''Traversable'\''
    and '\''Foldable'\'' that can be folded with just a '\''Semigroup'\'' are added.
category: Control, Comonads
abi: ccad4479a2b024d733bb9d4143fc493b
exposed: True
exposed-modules:
    Data.Bifunctor.Apply Data.Functor.Alt Data.Functor.Apply
    Data.Functor.Bind Data.Functor.Bind.Class Data.Functor.Bind.Trans
    Data.Functor.Extend Data.Functor.Plus Data.Groupoid
    Data.Isomorphism Data.Semigroup.Bifoldable
    Data.Semigroup.Bitraversable Data.Semigroup.Foldable
    Data.Semigroup.Foldable.Class Data.Semigroup.Traversable
    Data.Semigroup.Traversable.Class Data.Semigroupoid
    Data.Semigroupoid.Dual Data.Semigroupoid.Ob
    Data.Semigroupoid.Static Data.Traversable.Instances
import-dirs: /usr/lib/ghc-8.4.3/site-local/semigroupoids-5.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/semigroupoids-5.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/semigroupoids-5.3.1
hs-libraries: HSsemigroupoids-5.3.1-FqTO2wYzwLW2klA2dZbjqO
depends:
    base-4.11.1.0 base-orphans-0.8-DMkdJwLFak2DoFZzwzdOJW
    bifunctors-5.5.3-E9PcaLO1yNnFMXWSkSxpzv template-haskell-2.13.0.0
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    containers-0.5.11.0 contravariant-1.5-HWHOmzUIRDZBjbL8Fw1HTI
    distributive-0.6-IsVyilunZgICGjJYT3RUw
    comonad-5.0.4-12bsX4h9KMsLbkPFOtidp8
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-orphans-0.8-DMkdJwLFak2DoFZzwzdOJW=8fdd269bb784bcdf160da8c61c0e0531
             bifunctors-5.5.3-E9PcaLO1yNnFMXWSkSxpzv=51cdb9482f11aad88e712df6af0613f0
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             contravariant-1.5-HWHOmzUIRDZBjbL8Fw1HTI=745e81e7e3650c93ab38811415728ba3
             distributive-0.6-IsVyilunZgICGjJYT3RUw=f5bbf892f75e5889cad5d363c52f11d6
             comonad-5.0.4-12bsX4h9KMsLbkPFOtidp8=ff45cd9bde2c7650adda7acb6c1a8417
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
haddock-interfaces: /usr/share/doc/haskell-semigroupoids/html/semigroupoids.haddock
haddock-html: /usr/share/doc/haskell-semigroupoids/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
